==> rapid_widgets_library-0.2.54.tar.gz: lib/calendar.dart <==
import 'dart:collection';
import 'dart:convert';
import 'dart:math';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:http/http.dart' as http;
import 'package:flutter_clean_calendar/flutter_clean_calendar.dart';
import 'package:flutter_clean_calendar/clean_calendar_event.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'modify_event.dart';
import 'new_event.dart';
class CalendarEvent extends StatefulWidget {
  final CalendarEvent1 calendarEvent1;
   CalendarEvent({this.calendarEvent1}) ;
  @override
  _CalendarEventState createState() => _CalendarEventState();
}

class _CalendarEventState extends State<CalendarEvent> {
  DateTime _dateTime = DateTime(DateTime.now().year, DateTime.now().month, DateTime.now().day);
  final Map<DateTime, List<CleanCalendarEvent>> _events =   new HashMap();
  final Map<DateTime,List<Map<String,String>>> events = new HashMap();
  final Map<String,Map<String,List<Map<String,String>>>> event = new HashMap();
  bool copmleted_val = false;
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _handleNewDate(DateTime(DateTime.now().year, DateTime.now().month, DateTime.now().day));
  }
  TextEditingController controller = new TextEditingController();
  TimeOfDay time = TimeOfDay(hour: 0, minute: 0);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        height: widget.calendarEvent1.height??200,
        width: widget.calendarEvent1.width??200,
        child: Calendar(
          onRangeSelected: (range) =>

              print('Range is ${range.from}, ${range.to}'),

          onMonthChanged: (DateTime dateTime){
          },
          onDateSelected:(DateTime dateTime){
            /*  print(_events.toString());
             if(_events.containsKey(dateTime)){
               List<CleanCalendarEvent>ce =[];
               ce= _events[dateTime];
               for(int i=0;i<ce.length;i++){
                 print(ce[i].summary.toString());
                 print(ce[i].description.toString());
                 print(ce[i].location.toString());
                 print(ce[i].startTime.toString());
                 print(ce[i].endTime.toString());
                 print(ce[i].color.toString());
                 print(ce[i].isAllDay.toString());
                 print(ce[i].isDone.toString());
               }
             }*/
            setState(() {
              _dateTime =dateTime;
            });
            showDialog(
                context: context,
                builder: (context) => NewEventAlert(
                  dateTime: dateTime,
                  event_val: (String val1,String val2,TimeOfDay startTime,TimeOfDay endTime){
                    setState(() {
                      if(_events.containsKey(dateTime)){
                        String rand5 = getRandomString(5);
                        List<Map<String,String>>abcx=[];
                        Map <String, String>abc1= new HashMap();
                        abc1.putIfAbsent("Summary", () => val1.toString());
                        abc1.putIfAbsent("description", () => val1.toString());
                        abc1.putIfAbsent("uniqueId", () =>  rand5);
                        abc1.putIfAbsent("StartTime", () => startTime.toString());
                        abc1.putIfAbsent("EndTime", () => endTime.toString());
                        abc1.putIfAbsent("Completed", () => "False");
                        abcx= events[dateTime];
                        abcx.add(abc1);
                        events[dateTime]= abcx;

                        Map<String,List<Map<String,String>>>lm = new HashMap();
                        event[dateTime.toString()]=lm;
                        lm["details"] = abcx;
                        // print(event.toString());
                        fetchDataFromAPI(event);

                        List<CleanCalendarEvent>ce =[];
                        ce= _events[dateTime];
                        ce.add(CleanCalendarEvent(
                            val1.toString(),
                            description: val2.toString(),
                            location: rand5,
                            startTime: DateTime(DateTime.now().year, DateTime.now().month,
                                dateTime.day , startTime.hour, startTime.minute),
                            endTime: DateTime(DateTime.now().year, DateTime.now().month,
                                dateTime.day, endTime.hour, endTime.minute),
                            color: Colors.primaries[Random().nextInt(Colors.primaries.length)]));
                        _events[dateTime]= ce;






                      }
                      else{
                        String rand5 = getRandomString(5);
                        Map <String, String>abc= new HashMap();
                        abc.putIfAbsent("Summary", () => val1.toString());
                        abc.putIfAbsent("description", () => val1.toString());
                        abc.putIfAbsent("uniqueId", () => rand5);
                        abc.putIfAbsent("StartTime", () => startTime.toString());
                        abc.putIfAbsent("EndTime", () => endTime.toString());
                        abc.putIfAbsent("Completed", () => "False");
                        events.putIfAbsent(dateTime, () => [abc]);



                        Map<String,List<Map<String,String>>>lm = new HashMap();
                        lm.putIfAbsent("details", () => [abc]);
                        event.putIfAbsent(dateTime.toString(), () => lm);
                        //print(event.toString());
                        fetchDataFromAPI(event);


                        _events.putIfAbsent(dateTime, () =>   [CleanCalendarEvent(val1.toString(),
                            description: val2.toString(),
                            location: rand5,
                            startTime: DateTime(DateTime.now().year, DateTime.now().month,
                                dateTime.day , startTime.hour, startTime.minute),
                            endTime: DateTime(DateTime.now().year, DateTime.now().month,
                                dateTime.day, endTime.hour, endTime.minute),
                            color: Colors.primaries[Random().nextInt(Colors.primaries.length)])]);




                      }
                    });
                  },
                )
            );
          } ,
          onEventSelected: (CleanCalendarEvent cleanCalendarEvent){
            showDialog(context: context, builder:
                (context) => ModifyEvent(
              eventDesc: cleanCalendarEvent.description,
              eventName: cleanCalendarEvent.summary,
              startTime: cleanCalendarEvent.startTime,
              endTime: cleanCalendarEvent.endTime,
              copm_val: cleanCalendarEvent.isDone,
              event_val: (String val1,String val2,TimeOfDay startTime,TimeOfDay endTime,bool completed,String callBack){
                if(callBack == 'Yes'){
                  List<CleanCalendarEvent>ce =[];
                  List<Map<String,String>>abcxn=[];
                  abcxn = events[_dateTime];
                  ce = _events[_dateTime];
                 // print(abcxn.toString());
                  for(int j =0;j<abcxn.length;j++){
                    if(abcxn[j]["uniqueId"]==cleanCalendarEvent.location){
                      abcxn[j]["Summary"] = val1;
                      abcxn[j]["description"] =val2;
                      abcxn[j]["StartTime"] =startTime.toString();
                      abcxn[j]["EndTime"] =endTime.toString();
                      abcxn[j]["Completed"] =completed?"True":"False";
                    }
                  }

                  Map<String,List<Map<String,String>>>lm = new HashMap();
                  event[_dateTime.toString()]=lm;
                  lm["details"] = abcxn;
                  //print(event.toString());
                  fetchDataFromAPI(event);

                  //print(abcxn.toString());
                  for(int i= 0;i<ce.length;i++){
                    if(ce[i].location == cleanCalendarEvent.location ){
                      setState(() {
                        if(completed){
                          copmleted_val =completed;
                        }

                       // print('ce[i].location '+ce[i].location);
                        //print('cleanCalendarEvent.location '+cleanCalendarEvent.location );

                        ce[i] =  CleanCalendarEvent(val1,
                            description: val2,
                            isDone: completed,
                            location: cleanCalendarEvent.location,
                            startTime: DateTime(DateTime.now().year, DateTime.now().month,
                                _dateTime.day ,startTime.hour,startTime.minute),
                            endTime: DateTime(DateTime.now().year, DateTime.now().month,
                                _dateTime.day ,endTime.hour,endTime.minute),
                            color: ce[i].color
                        );
                      });
                    }
                  }
                }
                else if (callBack =='Delete'){
                  //print('fgxfg');
                  List<CleanCalendarEvent>ce =[];
                  ce = _events[_dateTime];
                  List<Map<String,String>>lst=[];
                  lst = events[_dateTime];
                  for(int j=0;j<lst.length;j++){
                    if(lst[j]["uniqueId"]==cleanCalendarEvent.location){
                      lst.removeAt(j);
                    }
                  }

                  for(int i= 0;i<ce.length;i++){
                    if(ce[i].location==cleanCalendarEvent.location){
                      setState(() {
                        ce.removeAt(i);
                      });
                    }
                  }
                  Map<String,List<Map<String,String>>>lm = new HashMap();
                  event[_dateTime.toString()]=lm;
                  lm["details"] = lst;
                  //print(event.toString());
                  fetchDataFromAPI(event);

                }
              },
            )
            );

          },
          startOnMonday: true,
          weekDays: ['Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa', 'Su'],
          events: _events,
          isExpandable: true,
          eventDoneColor: Colors.green,
          selectedColor: Colors.pink,
          todayColor: Colors.blue,
          eventColor: Colors.grey,
          locale: 'en_IN',
          todayButtonText: 'Today',
          isExpanded: true,
          expandableDateFormat: 'EEEE, dd. MMMM yyyy',
          dayOfWeekStyle: GoogleFonts.getFont('Roboto',
              color: Colors.black, fontWeight: FontWeight.w800, fontSize: 11),
        ),
      ),
    );
  }
  void _handleNewDate(date) {
    print('Date selected: $date');
  }
  static const _chars = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz1234567890';
  Random _rnd = Random();
  String getRandomString(int length) => String.fromCharCodes(Iterable.generate(
      length, (_) => _chars.codeUnitAt(_rnd.nextInt(_chars.length))));

  fetchDataFromAPI(Map<String,Map<String,List<Map<String,String>>>> eventparam) async {
    final response1 = await http.post(
      Uri.parse(widget.calendarEvent1.postApiUrl),
      headers: <String, String>{
        'Content-Type': 'application/json; charset=UTF-8',
      },
      body: jsonEncode(<String, String>{
        'title': 'Calendar_det',
        'event':eventparam.toString()
      }),
    );
    print("statusCode"+response1.statusCode.toString());
    print("headers"+response1.headers.toString());
    print("body"+response1.body.toString());
  }

}

==> rapid_widgets_library-0.2.58.tar.gz: lib/calendar.dart <==
import 'dart:collection';
import 'dart:convert';
import 'dart:math';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:http/http.dart' as http;
import 'package:flutter_clean_calendar/flutter_clean_calendar.dart';
import 'package:flutter_clean_calendar/clean_calendar_event.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'modify_event.dart';
import 'new_event.dart';
class CalendarEvent extends StatefulWidget {
  final CalendarEvent1 calendarEvent1;
   CalendarEvent({this.calendarEvent1}) ;
  @override
  _CalendarEventState createState() => _CalendarEventState();
}

class _CalendarEventState extends State<CalendarEvent> {
  DateTime _dateTime = DateTime(DateTime.now().year, DateTime.now().month, DateTime.now().day);
  final Map<DateTime, List<CleanCalendarEvent>> _events =   new HashMap();
  final Map<DateTime,List<Map<String,String>>> events = new HashMap();
  final Map<String,Map<String,List<Map<String,String>>>> event = new HashMap();
  bool copmleted_val = false;
  bool month_change=false;
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _handleNewDate(DateTime(DateTime.now().year, DateTime.now().month, DateTime.now().day));
  }
  TextEditingController controller = new TextEditingController();
  TimeOfDay time = TimeOfDay(hour: 0, minute: 0);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        height: widget.calendarEvent1.height??200,
        width: widget.calendarEvent1.width??200,
        child: Calendar(
          onRangeSelected: (range) {
            month_change=true;
          },
          onMonthChanged: (DateTime dateTime){
          },
          onDateSelected:(DateTime dateTime){
            if(month_change){
              month_change=!month_change;
              return;
            }
            /*  print(_events.toString());
             if(_events.containsKey(dateTime)){
               List<CleanCalendarEvent>ce =[];
               ce= _events[dateTime];
               for(int i=0;i<ce.length;i++){
                 print(ce[i].summary.toString());
                 print(ce[i].description.toString());
                 print(ce[i].location.toString());
                 print(ce[i].startTime.toString());
                 print(ce[i].endTime.toString());
                 print(ce[i].color.toString());
                 print(ce[i].isAllDay.toString());
                 print(ce[i].isDone.toString());
               }
             }*/
            setState(() {
              _dateTime =dateTime;
            });
            showDialog(
                context: context,
                builder: (context) => NewEventAlert(
                  dateTime: dateTime,
                  event_val: (String val1,String val2,TimeOfDay startTime,TimeOfDay endTime){
                    setState(() {
                      if(_events.containsKey(dateTime)){
                        String rand5 = getRandomString(5);
                        List<Map<String,String>>abcx=[];
                        Map <String, String>abc1= new HashMap();
                        abc1.putIfAbsent("Summary", () => val1.toString());
                        abc1.putIfAbsent("description", () => val1.toString());
                        abc1.putIfAbsent("uniqueId", () =>  rand5);
                        abc1.putIfAbsent("StartTime", () => startTime.toString());
                        abc1.putIfAbsent("EndTime", () => endTime.toString());
                        abc1.putIfAbsent("Completed", () => "False");
                        abcx= events[dateTime];
                        abcx.add(abc1);
                        events[dateTime]= abcx;

                        Map<String,List<Map<String,String>>>lm = new HashMap();
                        event[dateTime.toString()]=lm;
                        lm["details"] = abcx;
                        // print(event.toString());
                        fetchDataFromAPI(event);

                        List<CleanCalendarEvent>ce =[];
                        ce= _events[dateTime];
                        ce.add(CleanCalendarEvent(
                            val1.toString(),
                            description: val2.toString(),
                            location: rand5,
                            startTime: DateTime(DateTime.now().year, DateTime.now().month,
                                dateTime.day , startTime.hour, startTime.minute),
                            endTime: DateTime(DateTime.now().year, DateTime.now().month,
                                dateTime.day, endTime.hour, endTime.minute),
                            color: Colors.primaries[Random().nextInt(Colors.primaries.length)]));
                        _events[dateTime]= ce;






                      }
                      else{
                        String rand5 = getRandomString(5);
                        Map <String, String>abc= new HashMap();
                        abc.putIfAbsent("Summary", () => val1.toString());
                        abc.putIfAbsent("description", () => val1.toString());
                        abc.putIfAbsent("uniqueId", () => rand5);
                        abc.putIfAbsent("StartTime", () => startTime.toString());
                        abc.putIfAbsent("EndTime", () => endTime.toString());
                        abc.putIfAbsent("Completed", () => "False");
                        events.putIfAbsent(dateTime, () => [abc]);



                        Map<String,List<Map<String,String>>>lm = new HashMap();
                        lm.putIfAbsent("details", () => [abc]);
                        event.putIfAbsent(dateTime.toString(), () => lm);
                        //print(event.toString());
                        fetchDataFromAPI(event);


                        _events.putIfAbsent(dateTime, () =>   [CleanCalendarEvent(val1.toString(),
                            description: val2.toString(),
                            location: rand5,
                            startTime: DateTime(DateTime.now().year, DateTime.now().month,
                                dateTime.day , startTime.hour, startTime.minute),
                            endTime: DateTime(DateTime.now().year, DateTime.now().month,
                                dateTime.day, endTime.hour, endTime.minute),
                            color: Colors.primaries[Random().nextInt(Colors.primaries.length)])]);




                      }
                    });
                  },
                )
            );
          } ,
          onEventSelected: (CleanCalendarEvent cleanCalendarEvent){
            showDialog(context: context, builder:
                (context) => ModifyEvent(
              eventDesc: cleanCalendarEvent.description,
              eventName: cleanCalendarEvent.summary,
              startTime: cleanCalendarEvent.startTime,
              endTime: cleanCalendarEvent.endTime,
              copm_val: cleanCalendarEvent.isDone,
              event_val: (String val1,String val2,TimeOfDay startTime,TimeOfDay endTime,bool completed,String callBack){
                if(callBack == 'Yes'){
                  List<CleanCalendarEvent>ce =[];
                  List<Map<String,String>>abcxn=[];
                  abcxn = events[_dateTime];
                  ce = _events[_dateTime];
                 // print(abcxn.toString());
                  for(int j =0;j<abcxn.length;j++){
                    if(abcxn[j]["uniqueId"]==cleanCalendarEvent.location){
                      abcxn[j]["Summary"] = val1;
                      abcxn[j]["description"] =val2;
                      abcxn[j]["StartTime"] =startTime.toString();
                      abcxn[j]["EndTime"] =endTime.toString();
                      abcxn[j]["Completed"] =completed?"True":"False";
                    }
                  }

                  Map<String,List<Map<String,String>>>lm = new HashMap();
                  event[_dateTime.toString()]=lm;
                  lm["details"] = abcxn;
                  //print(event.toString());
                  fetchDataFromAPI(event);

                  //print(abcxn.toString());
                  for(int i= 0;i<ce.length;i++){
                    if(ce[i].location == cleanCalendarEvent.location ){
                      setState(() {
                        if(completed){
                          copmleted_val =completed;
                        }

                       // print('ce[i].location '+ce[i].location);
                        //print('cleanCalendarEvent.location '+cleanCalendarEvent.location );

                        ce[i] =  CleanCalendarEvent(val1,
                            description: val2,
                            isDone: completed,
                            location: cleanCalendarEvent.location,
                            startTime: DateTime(DateTime.now().year, DateTime.now().month,
                                _dateTime.day ,startTime.hour,startTime.minute),
                            endTime: DateTime(DateTime.now().year, DateTime.now().month,
                                _dateTime.day ,endTime.hour,endTime.minute),
                            color: ce[i].color
                        );
                      });
                    }
                  }
                }
                else if (callBack =='Delete'){
                  //print('fgxfg');
                  List<CleanCalendarEvent>ce =[];
                  ce = _events[_dateTime];
                  List<Map<String,String>>lst=[];
                  lst = events[_dateTime];
                  for(int j=0;j<lst.length;j++){
                    if(lst[j]["uniqueId"]==cleanCalendarEvent.location){
                      lst.removeAt(j);
                    }
                  }

                  for(int i= 0;i<ce.length;i++){
                    if(ce[i].location==cleanCalendarEvent.location){
                      setState(() {
                        ce.removeAt(i);
                      });
                    }
                  }
                  Map<String,List<Map<String,String>>>lm = new HashMap();
                  event[_dateTime.toString()]=lm;
                  lm["details"] = lst;
                  //print(event.toString());
                  fetchDataFromAPI(event);

                }
              },
            )
            );

          },
          startOnMonday: true,
          weekDays: ['Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa', 'Su'],
          events: _events,
          isExpandable: true,
          eventDoneColor: Colors.green,
          selectedColor: Colors.pink,
          todayColor: Colors.blue,
          eventColor: Colors.grey,
          locale: 'en_IN',
          todayButtonText: 'Today',
          isExpanded: true,
          expandableDateFormat: 'EEEE, dd. MMMM yyyy',
          dayOfWeekStyle: GoogleFonts.getFont('Roboto',
              color: Colors.black, fontWeight: FontWeight.w800, fontSize: 11),
        ),
      ),
    );
  }
  void _handleNewDate(date) {
    print('Date selected: $date');
  }
  static const _chars = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz1234567890';
  Random _rnd = Random();
  String getRandomString(int length) => String.fromCharCodes(Iterable.generate(
      length, (_) => _chars.codeUnitAt(_rnd.nextInt(_chars.length))));

  fetchDataFromAPI(Map<String,Map<String,List<Map<String,String>>>> eventparam) async {
    final response1 = await http.post(
      Uri.parse(widget.calendarEvent1.postApiUrl),
      headers: <String, String>{
        'Content-Type': 'application/json; charset=UTF-8',
      },
      body: jsonEncode(<String, String>{
        'title': 'Calendar_det',
        'event':eventparam.toString()
      }),
    );
    print("statusCode"+response1.statusCode.toString());
    print("headers"+response1.headers.toString());
    print("body"+response1.body.toString());
  }

}
